# starparse [<img src="https://img.shields.io/gitlab/pipeline/alen/starparse/main?gitlab_url=https%3A%2F%2Fgitlab.home.alen.sh%2F&label=Gitlab%20CI&style=flat-square" align="right">](https://gitlab.home.alen.sh/alen/starparse) [<img src="https://img.shields.io/travis/buhanec/starparse/main.svg?label=Travis+CI&style=flat-square" align="right">](https://travis-ci.org/buhanec/starparse) [<img src="https://img.shields.io/azure-devops/build/buhanec/b18841f7-3636-4121-b15f-f924dc02c956/4/main?label=Azure%20DevOps&style=flat-square" align="right">](https://dev.azure.com/buhanec/starparse/_build)

Small Python project to parse save game files for Starbound.

Works with 1.0.x / nightly save files, both to unpack and re-pack.

Look at [`tests/test_e2e.py`](tests/test_e2e.py) for an example of reading a save file.
